@@ -311,15 +311,12 @@ int World::detect()
 int World::detect_scroll()
 {
    int scroll_x = 0, scroll_y = 0;
-   if( !vga.is_input_grabbed() && !mouse.get_scroll(&scroll_x, &scroll_y))
-      return 0;
+
+   mouse.get_scroll(&scroll_x, &scroll_y);
 
    if( mouse_cursor.frame_flag )    // if it's now in frame selection mode
       return 0;
 
-   if( next_scroll_time && misc.get_time() < next_scroll_time )      // just scrolled not too long ago, wait for a little while before next scroll.
-      return 0;
-
    int rc=0;
 
    if ( scroll_x || scroll_y )
@@ -327,32 +324,35 @@ int World::detect_scroll()
        zoom_matrix->scroll(scroll_x, scroll_y);
        rc = 1;
    }
-   else
+   else if( vga.is_input_grabbed() )
    {
+       if( next_scroll_time && misc.get_time() < next_scroll_time )      // just scrolled not too long ago, wait for a little while before next scroll.
+           return 0;
+
        //----- scroll left -----//
 
-       if (mouse.cur_x <= mouse.bound_x1) {
+       if (mouse.cur_x <= mouse.bound_x1 + config_adv.fix_world_warp_slop) {
            zoom_matrix->scroll(-1, 0);
            rc = 1;
        }
 
        //---- scroll right -----//
 
-       if (mouse.cur_x >= mouse.bound_x2) {
+       if (mouse.cur_x >= mouse.bound_x2 - config_adv.fix_world_warp_slop) {
            zoom_matrix->scroll(1, 0);
            rc = 1;
        }
 
        //---- scroll top -------//
 
-       if (mouse.cur_y <= mouse.bound_y1) {
+       if (mouse.cur_y <= mouse.bound_y1 + config_adv.fix_world_warp_slop) {
            zoom_matrix->scroll(0, -1);
            rc = 1;
        }
 
        //---- scroll bottom ----//
 
-       if (mouse.cur_y >= mouse.bound_y2) {
+       if (mouse.cur_y >= mouse.bound_y2 - config_adv.fix_world_warp_slop) {
            zoom_matrix->scroll(0, 1);
            rc = 1;
        }
